from enum import Enum, unique
from .color import Color

@unique
class BrightColor(Enum):
    GREEN   = "\033[92m"
    YELLOW  = "\033[93m"
    RED     = "\033[91m"
    MAGENTA = "\033[95m"
    BLUE    = "\033[94m"
    CYAN    = "\033[96m"
    WHITE   = "\033[97m"
    BLACK   = "\033[90m"
    DEFAULT = Color.DEFAULT
    OFF     = Color.OFF

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum, unique

@unique
class Color(Enum):
    GREEN   = "\033[32m"
    YELLOW  = "\033[33m"
    RED     = "\033[31m"
    MAGENTA = "\033[35m"
    BLUE    = "\033[34m"
    CYAN    = "\033[36m"
    WHITE   = "\033[37m"
    BLACK   = "\033[30m"
    DEFAULT = "\033[39m"
    OFF     = "\033[0m"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum, unique
from .color import Color

@unique
class BgColor(Enum):
    GREEN   = "\033[42m"
    YELLOW  = "\033[43m"
    RED     = "\033[41m"
    MAGENTA = "\033[45m"
    BLUE    = "\033[44m"
    CYAN    = "\033[46m"
    WHITE   = "\033[47m"
    BLACK   = "\033[40m"
    DEFAULT = "\033[49m"
    OFF     = Color.OFF

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum, unique

from .background_color import BgColor
from .color import Color

@unique
class BgBrightColor(Enum):
    GREEN   = "\033[102m"
    YELLOW  = "\033[103m"
    RED     = "\033[101m"
    MAGENTA = "\033[105m"
    BLUE    = "\033[104m"
    CYAN    = "\033[106m"
    WHITE   = "\033[107m"
    BLACK   = "\033[100m"
    DEFAULT = BgColor.DEFAULT
    OFF     = Color.OFF

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum, unique
from .color import Color

@unique
class Effect(Enum):
    BOLD      = "\033[1m"
    DIM       = "\033[2m"
    UNDERLINE = "\033[4m"
    BLINK     = "\033[5m"
    REVERSE   = "\033[7m"
    HIDE      = "\033[8m"

    BOLD_OFF      = "\033[21m"
    DIM_OFF       = "\033[22m"
    UNDERLINE_OFF = "\033[24m"
    BLINK_OFF     = "\033[25m"
    REVERSE_OFF   = "\033[27m"
    HIDE_OFF      = "\033[28m"
    OFF           = Color.OFF

    def __str__(self) -> str:
        return str(self.value)
